View source: R/as.data.frame.R
| as.data.frame.seas | R Documentation |
data.frameThese methods coerce the output to a data.frame. This is useful for
further processing. (This is a second attempt to do that; the first
experimental attempt in version 1.4 used an argument data.frame in the
call to the functions, and is now obsolete. The present approach seems
cleaner and is likely to stay, but still consider it as
experimental.)
## S3 method for class 'seas'
as.data.frame(x, ...)
## S3 method for class 'summary.seas'
as.data.frame(x, ...)
x |
an object of class |
... |
unused. |
The data.frames follow the naming conventions of the 'broom' package, but
do not depend on it. tidy(), augment() and glance() return the same
data, as soon as a package that provides these generics is loaded.
a data.frame without row names.
m <- seas(AirPassengers, x11 = "")
# a data.frame containing data
as.data.frame(m)
# a data.frame containing the summary information on the coefficients
as.data.frame(summary(m))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.