These methods coerce the output to a data.frame. This is useful for
further processing. (This is a second attempt to do that; the first
experimental attempt in version 1.4 used an argument data.frame in the
call to the functions, and is now obsolete. The present approach seems
cleaner and is likely to stay, but still consider it as
experimental.)
Usage
# S3 method for seas
as.data.frame(x, ...)
# S3 method for summary.seas
as.data.frame(x, ...)
Value
a data.frame without row names.
Arguments
x
an object of class "seas" or
"summary.seas", usually, the result of a call to the functions
with the same name.
...
unused.
Details
The data.frames follow the naming conventions of the 'broom' package, but
do not depend on it. tidy(), augment() and glance() return the same
data, as soon as a package that provides these generics is loaded.
# \donttest{m <- seas(AirPassengers, x11 = "")
# a data.frame containing dataas.data.frame(m)
# a data.frame containing the summary information on the coefficientsas.data.frame(summary(m))
# }